@@ -50,7 +50,7 @@ class WidgyPageAdminForm(WidgyFormMixin, PageAdminForm):
         self.fields['expiry_date'].help_text = _(
             "If you enter a date here, the page will not be viewable after this time"
         )
-        if self.instance.pk is not None:
+        if self.instance.pk is None:
             self.instance.status = CONTENT_STATUS_DRAFT
 
 
@@ -167,7 +167,7 @@ class WidgyPageAdmin(PageAdmin):
         else:
             context['save_buttons'] = self.unreviewed_buttons[status]
         if not add:
-            context['history_url'] =  site.reverse(site.history_view, kwargs={'pk': obj.pk})
+            context['history_url'] =  site.reverse(site.history_view, kwargs={'pk': obj.root_node_id})
         return super(WidgyPageAdmin, self).render_change_form(request, context, add, change, form_url, obj, *args, **kwargs)
 
     @property
